[Zope-CVS] CVS: Products/AdaptableStorage/serial/interfaces - IClassifier.py:1.3 IDeserializationEvent.py:1.3 IKeyedObjectSystem.py:1.3

Shane Hathaway shane@zope.com
Sat, 7 Dec 2002 00:59:44 -0500


Update of /cvs-repository/Products/AdaptableStorage/serial/interfaces
In directory cvs.zope.org:/tmp/cvs-serv21888/serial/interfaces

Modified Files:
	IClassifier.py IDeserializationEvent.py IKeyedObjectSystem.py 
Log Message:
Fixed the bugs in the new strategy (OIDs no longer include mapper_names, 
allowing more flexibility in loading and storage).  Did not resolve new
key generation yet, but everything else seems to be in good shape.


=== Products/AdaptableStorage/serial/interfaces/IClassifier.py 1.2 => 1.3 ===
--- Products/AdaptableStorage/serial/interfaces/IClassifier.py:1.2	Fri Dec  6 17:06:50 2002
+++ Products/AdaptableStorage/serial/interfaces/IClassifier.py	Sat Dec  7 00:59:13 2002
@@ -36,12 +36,12 @@
         """Returns a classification and mapper_name.
         """
 
-    def classifyState(mapper, keychain):
+    def classifyState(object_mapper, keychain):
         """Returns a classification and mapper_name.
 
         May load the classification from storage.
         """
 
-    def store(mapper, keychain, classification):
+    def store(object_mapper, keychain, classification):
         """Stores the classification of an object.
         """


=== Products/AdaptableStorage/serial/interfaces/IDeserializationEvent.py 1.2 => 1.3 ===
--- Products/AdaptableStorage/serial/interfaces/IDeserializationEvent.py:1.2	Fri Dec  6 17:06:50 2002
+++ Products/AdaptableStorage/serial/interfaces/IDeserializationEvent.py	Sat Dec  7 00:59:13 2002
@@ -28,7 +28,7 @@
         """Indicates that a named internal subobject was deserialized.
         """
 
-    def dereference(name, keychain):
+    def dereference(name, keychain, mapper_names=None):
         """Retrieves a referenced subobject (usually ghosted initially).
         """
 


=== Products/AdaptableStorage/serial/interfaces/IKeyedObjectSystem.py 1.2 => 1.3 ===
--- Products/AdaptableStorage/serial/interfaces/IKeyedObjectSystem.py:1.2	Fri Dec  6 17:06:50 2002
+++ Products/AdaptableStorage/serial/interfaces/IKeyedObjectSystem.py	Sat Dec  7 00:59:13 2002
@@ -21,10 +21,10 @@
 class IKeyedObjectSystem (Interface):
     """A collection of objects identifiable by keychain."""
 
-    def loadStub(keychain, class_info=None):
+    def loadStub(keychain, mapper_names=None):
         """Returns a class instance, possibly ghosted.
 
         class_info is provided as a possible optimization.  Without
         it, this method may have to load a full object rather than a
         ghosted object.
         """
@@ -21,10 +21,10 @@
         """Returns a class instance, possibly ghosted.
 
-        class_info is provided as a possible optimization.  Without
+        mapper_names is provided as a possible optimization.  Without
         it, this method may have to load a full object rather than a
         ghosted object.